==> components-2.3.2.tgz: package/esm/Organisms/Navbar/NavbarToggler.js <==
import React from 'react';
import PropTypes from 'prop-types';
import styled from 'styled-components';
import { FasTimes, FasBars } from '../../Atoms/Icons';
var TogglerExpand =
/*#__PURE__*/
styled(FasTimes).attrs({
  selectable: true,
  size: '20px'
}).withConfig({
  componentId: "sc-1til0ak-0"
})(["\n  z-index: 15;\n  fill: ", " !important;\n\n  &:hover {\n    fill: ", " !important;\n  }\n\n  @media (min-width: ", ") {\n    display: none;\n  }\n"], function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme.screenSizes.sm;
});
var TogglerCollapse =
/*#__PURE__*/
styled(FasBars).attrs({
  selectable: true,
  size: '25px'
}).withConfig({
  componentId: "sc-1til0ak-1"
})(["\n  z-index: 15;\n  fill: ", " !important;\n\n  &:hover {\n    fill: ", " !important;\n  }\n\n  @media (min-width: ", ") {\n    display: none;\n  }\n"], function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme.screenSizes.sm;
});

var NavbarToggler = function NavbarToggler(_ref) {
  var onToggle = _ref.onToggle,
      toggled = _ref.toggled;
  return toggled ? React.createElement(TogglerExpand, {
    onClick: onToggle
  }) : React.createElement(TogglerCollapse, {
    onClick: onToggle
  });
};

NavbarToggler.propTypes = process.env.NODE_ENV !== "production" ? {
  onToggle: PropTypes.func.isRequired,
  toggled: PropTypes.bool
} : {};
NavbarToggler.defaultProps = {
  toggled: false
};
export default NavbarToggler;

==> components-2.4.1.tgz: package/esm/Organisms/Navbar/NavbarToggler.js <==
//  strict
import PropTypes from 'prop-types';
import React from 'react';
import styled from 'styled-components';
import { FasTimes, FasBars } from '../../Atoms/Icons';
var TogglerExpand =
/*#__PURE__*/
styled(FasTimes).attrs({
  selectable: true,
  size: '20px'
}).withConfig({
  componentId: "sc-1til0ak-0"
})(["\n  z-index: 15;\n  fill: ", " !important;\n\n  &:hover {\n    fill: ", " !important;\n  }\n\n  @media (min-width: ", ") {\n    display: none;\n  }\n"], function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme.screenSizes.sm;
});
var TogglerCollapse =
/*#__PURE__*/
styled(FasBars).attrs({
  selectable: true,
  size: '25px'
}).withConfig({
  componentId: "sc-1til0ak-1"
})(["\n  z-index: 15;\n  fill: ", " !important;\n\n  &:hover {\n    fill: ", " !important;\n  }\n\n  @media (min-width: ", ") {\n    display: none;\n  }\n"], function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme['navbarTogglerColor'];
}, function (props) {
  return props.theme.screenSizes.sm;
});

var NavbarToggler = function NavbarToggler(_ref) {
  var onToggle = _ref.onToggle,
      toggled = _ref.toggled;
  return toggled === true ? React.createElement(TogglerExpand, {
    onClick: onToggle
  }) : React.createElement(TogglerCollapse, {
    onClick: onToggle
  });
};

NavbarToggler.propTypes = process.env.NODE_ENV !== "production" ? {
  onToggle: PropTypes.func.isRequired,
  toggled: PropTypes.bool
} : {};
NavbarToggler.defaultProps = {
  toggled: false
};
export default NavbarToggler;
